==> repro_flutter-2.1.0.tar.gz: example/lib/test/test_helper.dart <==
library io.repro.flutter.test;

import 'package:flutter/material.dart';
import 'package:flutter/rendering.dart';
import 'package:repro_flutter/repro.dart';

part 'test_newsfeeds.dart';

class ManualAppTester {
  Map<String, TestRunner> _testClassList;

  ManualAppTester() {
    _testClassList = Map<String, TestRunner>();
    _testClassList["NewsFeeds"] = NewsFeedsTestRunner();
  }

  Future<void> run() async {
    debugPrint("===== Start testing =====");
    await Future.forEach(_testClassList.entries, (MapEntry entry) async {
      debugPrint("*** ${entry.key} ***");
      await entry.value.run();
    });
    debugPrint("===== Test finished =====");
  }
}

class TestRunner {

  Future<void> run() => null;

  Future<bool> test(String description, Future<Object> Function() func, bool Function(TestResult res) condition) async {
    
    Object result; // Exception or Error
    Object exception;
    try {
      result = await func();
    } catch (e) {
      exception = e;
    }
    
    var testResult = TestResult(exception, result);
    StackTrace trace;
    bool conditionCheckResult;

    try {
      conditionCheckResult = condition(testResult);
    } catch (e, stackTrace) {
      conditionCheckResult = false;
      trace = stackTrace;
    }

    if (conditionCheckResult) {
      _output("✅ Success: $description");
    } else {
      var text = "❌ Failure: $description";
      if (testResult.hasException() && trace != null) {
        text += "\n" + trace.toString();
      }
      _output(text);
    }

    return conditionCheckResult;
  }

  void _output(String text) {
    debugPrint(text);
  }
}

class TestResult {
  Object _exception;
  Object _result;

  Object get exception => _exception;
  Object get result => _result;

  TestResult(this._exception, this._result);
  bool hasException() => _exception != null;
}

==> repro_flutter-3.6.0.tar.gz: example/lib/test/test_helper.dart <==
library io.repro.flutter.test;

import 'package:flutter/material.dart';
import 'package:flutter/rendering.dart';
import 'package:repro_flutter/repro.dart';

part 'test_newsfeeds.dart';

class ManualAppTester {
  late Map<String, TestRunner> _testClassList;

  ManualAppTester() {
    _testClassList = Map<String, TestRunner>();
    _testClassList["NewsFeeds"] = NewsFeedsTestRunner();
  }

  Future<void> run() async {
    debugPrint("===== Start testing =====");
    await Future.forEach(_testClassList.entries, (MapEntry entry) async {
      debugPrint("*** ${entry.key} ***");
      await entry.value.run();
    });
    debugPrint("===== Test finished =====");
  }
}

abstract class TestRunner {

  Future<void> run();

  Future<bool> test(String description, Future<Object> Function() func, bool Function(TestResult res) condition) async {
    
    Object? result; // Exception or Error
    Object? exception;
    try {
      result = await func();
    } catch (e) {
      exception = e;
    }
    
    var testResult = TestResult(exception, result);
    StackTrace? trace;
    bool conditionCheckResult;

    try {
      conditionCheckResult = condition(testResult);
    } catch (e, stackTrace) {
      conditionCheckResult = false;
      trace = stackTrace;
    }

    if (conditionCheckResult) {
      _output("✅ Success: $description");
    } else {
      var text = "❌ Failure: $description";
      if (testResult.hasException() && trace != null) {
        text += "\n" + trace.toString();
      }
      _output(text);
    }

    return conditionCheckResult;
  }

  void _output(String text) {
    debugPrint(text);
  }
}

class TestResult {
  Object? _exception;
  Object? _result;

  Object? get exception => _exception;
  Object? get result => _result;

  TestResult(this._exception, this._result);
  bool hasException() => _exception != null;
}
